=========================================
Climate Impact Lab development toolkit
=========================================

.. image:: https://img.shields.io/pypi/v/impactlab-tools.svg
        :target: https://pypi.python.org/pypi/impactlab-tools

.. image:: https://travis-ci.org/ClimateImpactLab/impactlab-tools.svg?branch=master
        :target: https://travis-ci.org/ClimateImpactLab/impactlab-tools?branch=master

.. image:: https://coveralls.io/repos/github/ClimateImpactLab/impactlab-tools/badge.svg?branch=master
        :target: https://coveralls.io/github/ClimateImpactLab/impactlab-tools?branch=master

.. image:: https://www.readthedocs.io/projects/impactlab-tools/badge/?version=latest
        :target: https://impactlab-tools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/ClimateImpactLab/impactlab-tools/shield.svg
     :target: https://pyup.io/repos/github/ClimateImpactLab/impactlab-tools/
     :alt: Updates

.. image:: https://pyup.io/repos/github/ClimateImpactLab/impactlab-tools/python-3-shield.svg
     :target: https://pyup.io/repos/github/ClimateImpactLab/impactlab-tools/
     :alt: Python 3

.. image:: https://api.codacy.com/project/badge/Grade/2d53428d5e5e41ecbc673208b2b0692c
   :alt: Codacy Badge
   :target: https://www.codacy.com/app/delgadom/impactlab-tools?utm_source=github.com&utm_medium=referral&utm_content=ClimateImpactLab/impactlab-tools&utm_campaign=badger

Python tools for Climate Impact Lab developers


* Documentation: http://impactlab-tools.readthedocs.io/en/latest/.


Features
--------

* Out-of-the-box aggregation & weighting using Impactlab regions & datasets
* Computes distributions across ACP and GCP models
* Provides tools for using Climate Impact Lab server configuration files
* Integrates seamlessly into pandas and xarray workflows


Usage
-----

For detailed usage instructions, see the `readthedocs documentation <https://impactlab-tools.readthedocs.io/en/latest/>`_

Installation
------------

``pip install impactlab-tools``


Requirements
------------

This package requires python version 2.7 or python 3 (3.4 or higher).
Installing with pip will ensure all dependencies are installed correctly.


Latest Release Notes
--------------------

See `whatsnew <https://github.com/ClimateImpactLab/impactlab-tools/blob/master/whatsnew.rst>`_


Todo
----

See `issues <https://bitbucket.org/ClimateImpactLab/impactlab-tools/issues>`_ to see and add to our todos.


Credits
---------

This package was created by `Justin Simcock <https://github.com/jgerardsimcock>`_ and `Michael Delgado <https://github.com/delgadom>`_ of the `Climate Impact Lab <http://impactlab.org>`_. Check us out on `github <https://github.com/ClimateImpactLab>`_.
